# spetlr-boot
A tiny project that can install libraries from a folder before running an entry point

# Design principles
The library has no dependencies and this should always be maintained. This is what allows this library to 
function as a bootstrap.

